package app.insti.activity;

import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Toast;

import com.google.android.material.floatingactionbutton.FloatingActionButton;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.ValueEventListener;
import com.google.firebase.storage.StorageReference;

import java.util.ArrayList;
import java.util.List;

import app.insti.R;
import app.insti.adapter.MyEventAdapter;
import app.insti.adapter.SubActivitiesAdapter;
import app.insti.api.model.MyEvent;
import app.insti.api.model.SubActivity;

public class EventActivity extends AppCompatActivity implements MyEventAdapter.OnMyEventListener {

    private static final String TAG = "Events";
    private RecyclerView recyclerView;
    private StorageReference storageReference;
    private DatabaseReference databaseReference;
    private List<MyEvent> myEventList = new ArrayList<>();
    private MyEventAdapter myEventAdapter;
    private MyEventAdapter.OnMyEventListener myEventListener;
    private String subActivityNameClicked;
    private FloatingActionButton floatingActionButton;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        //Toast.makeText(getApplicationContext(),getIntent().getStringExtra("subActivityNameClicked"),Toast.LENGTH_SHORT).show();
        setContentView(R.layout.activity_event);
        recyclerView = findViewById(R.id.myEventRecyclerView);
        floatingActionButton = findViewById(R.id.add_event);
        subActivityNameClicked = getIntent().getStringExtra("subActivityNameClicked");
        initRecyclerView();
        insertMyEvents();

        floatingActionButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(EventActivity.this,CreateEventActivity.class);
                startActivity(intent);
            }
        });
    }

    private void insertMyEvents() {
        databaseReference = FirebaseDatabase.getInstance().getReference("my_events");
        databaseReference.addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                // This method is called once with the initial value and again
                // whenever data at this location is updated.
                for(DataSnapshot activitySnapshot : dataSnapshot.getChildren()){
                    MyEvent myEvent = activitySnapshot.getValue(MyEvent.class);
                    String myEventParent = myEvent.getMyEventParent();
                    if(myEventParent.equals(subActivityNameClicked)) {
                        myEventList.add(myEvent);
                    }
                }

                MyEventAdapter myEventAdapter = new MyEventAdapter(myEventList,myEventListener);
                recyclerView.setAdapter(myEventAdapter);
            }

            @Override
            public void onCancelled(DatabaseError error) {
                // Failed to read value
                Log.w(TAG, "Failed to read value.", error.toException());
            }
        });
    }

    private void initRecyclerView() {
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this);
        recyclerView.setLayoutManager(linearLayoutManager);
        myEventListener = this;
        myEventAdapter = new MyEventAdapter(myEventList,myEventListener);
        recyclerView.setAdapter(myEventAdapter);

        setSupportActionBar(findViewById(R.id.toolbar));
        setTitle("Sub Activities");
    }

    @Override
    public void onMyEventClick(int position) {
//        Toast.makeText(getApplicationContext(),"message",Toast.LENGTH_SHORT).show();
        Intent intent = new Intent(this,EventDescriptionActivity.class);
        intent.putExtra("eventNameClicked",myEventList.get(position).getMyEventID());
        startActivity(intent);
    }


}
