package app.insti.adapter;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;
import app.insti.Utils;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentActivity;
import androidx.fragment.app.FragmentManager;
import androidx.fragment.app.FragmentTransaction;
import androidx.recyclerview.widget.RecyclerView;

import com.squareup.picasso.Picasso;

import java.util.ArrayList;
import java.util.List;

import app.insti.R;
import app.insti.api.model.BroadActivity;

public class ActivitiesAdapter extends RecyclerView.Adapter<ActivitiesAdapter.BroadActivitiesViewHolder> {

    private List<BroadActivity> broadActivityList = new ArrayList<>();
    private OnBroadActivityListener onBroadActivityListener;

    public ActivitiesAdapter(List<BroadActivity> broadActivityList,OnBroadActivityListener onBroadActivityListener){
        this.broadActivityList = broadActivityList;
        this.onBroadActivityListener = onBroadActivityListener;
    }

    @NonNull
    @Override
    public BroadActivitiesViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        LayoutInflater inflater = LayoutInflater.from(parent.getContext());
        View view = inflater.inflate(R.layout.resource_layout_broad_activities,parent,false);
        return new BroadActivitiesViewHolder(view,onBroadActivityListener);
    }

    @Override
    public void onBindViewHolder(@NonNull BroadActivitiesViewHolder holder, int position) {
        BroadActivity broadActivity = broadActivityList.get(position);
        holder.txtView.setText(broadActivity.getBroadActivityName());
        Picasso.get().load(broadActivity.getAvatarUrl()).fit().centerCrop().into(holder.imgView);
    }

    @Override
    public int getItemCount() {
        return broadActivityList.size();
    }

    public class BroadActivitiesViewHolder extends RecyclerView.ViewHolder implements View.OnClickListener {
        ImageView imgView;
        TextView txtView;
        LinearLayout linearLayoutActivity;
        OnBroadActivityListener onBroadActivityListener;

        public BroadActivitiesViewHolder(@NonNull View itemView, OnBroadActivityListener onBroadActivityListener) {
            super(itemView);
            imgView = itemView.findViewById(R.id.imgViewActivity);
            txtView = itemView.findViewById(R.id.txtViewActivity);
            linearLayoutActivity = itemView.findViewById(R.id.linearLayoutActivity);
            this.onBroadActivityListener = onBroadActivityListener;
            itemView.setOnClickListener(this);

        }

        @Override
        public void onClick(View v) {
            System.out.println("*************************************************");
            System.out.println(getAdapterPosition());
            System.out.println("*************************************************");
            onBroadActivityListener.onBroadActivityClick(getAdapterPosition());
        }
    }

    public interface OnBroadActivityListener{
        void onBroadActivityClick(int position);
    }
}
